@@ -77,7 +77,7 @@ BINDIR=$INSTALLDIR/bin		# main dir for binary stuff
 CONFIGDIR=$ROOT/config
 HEAPDIR=$BINDIR/.heap		# where heap images live
 RUNDIR=$BINDIR/.run		# where executables (i.e., the RTS) live
-SRCDIR=$ROOT/src		# where the source tree is rooted
+BASEDIR=$ROOT/base		# where the base source tree is rooted
 LIBDIR=$INSTALLDIR/lib		# where libraries live
 
 #
@@ -98,7 +98,6 @@ trap 'cd "$ROOT"; rm -f $tmpfiles' 0 1 2 3 15
 #
 export CM_PATHCONFIG
 CM_PATHCONFIG=$LIBDIR/pathconfig
-
 #
 # the release version that we are installing
 #
@@ -207,7 +206,7 @@ dirarcs() {
 #
 # create the various sub directories
 #
-for dir in "$BINDIR" "$HEAPDIR" "$RUNDIR" "$LIBDIR" "$SRCDIR" ; do
+for dir in "$BINDIR" "$HEAPDIR" "$RUNDIR" "$LIBDIR" "$BASEDIR" ; do
     makedir "$dir"
 done
 
@@ -229,6 +228,7 @@ installdriver() {
 	cat "$CONFIGDIR"/"$dsrc" | \
 	sed -e "s,@SHELL@,$SHELL,g" \
 	    -e "s,@BINDIR@,$BINDIR," \
+	    -e "s,@LIBDIR@,$LIBDIR," \
 	    -e "s,@VERSION@,$VERSION," \
 	    -e "s,@CMDIRARC@,${CM_DIR_ARC:-dummy}," \
 	    > "$BINDIR"/"$ddst"
@@ -317,7 +317,7 @@ if [ -x "$RUNDIR"/run.$ARCH-$OPSYS ]; then
     vsay $this: Run-time system already exists.
 else
     "$CONFIGDIR"/unpack "$ROOT" runtime
-    cd "$SRCDIR"/runtime/objs
+    cd "$BASEDIR"/runtime/objs
     echo $this: Compiling the run-time system.
     $MAKE -f mk.$ARCH-$OPSYS $EXTRA_DEFS
     if [ -x run.$ARCH-$OPSYS ]; then
@@ -325,19 +325,25 @@ else
 	if [ -f runx.$ARCH-$OPSYS ]; then
 	    mv runx.$ARCH-$OPSYS "$RUNDIR"
 	fi
+	if [ -f run.$ARCH-$OPSYS.so ]; then
+	    mv run.$ARCH-$OPSYS.so "$RUNDIR"
+	fi
+	if [ -f run.$ARCH-$OPSYS.a ]; then
+	    mv run.$ARCH-$OPSYS.a "$RUNDIR"
+	fi
 	$MAKE MAKE=$MAKE clean
     else
 	complain "$this: !!! Run-time system build failed for some reason."
     fi
 fi
-cd "$SRCDIR"
+cd "$BASEDIR"
 
 #
 # boot the base SML system
 #
 if [ -r "$HEAPDIR"/sml.$HEAP_SUFFIX ]; then
     vsay $this: Heap image $HEAPDIR/sml.$HEAP_SUFFIX already exists.
-    fish "$LIBDIR"/basis.cm
+    fish "$LIBDIR"/smlnj/basis
     # ignore requested arc name since we have to live with what is there:
     export CM_DIR_ARC
     CM_DIR_ARC=$ORIG_CM_DIR_ARC
@@ -353,7 +359,7 @@ if [ -r "$HEAPDIR"/sml.$HEAP_SUFFIX ]; then
 else
     "$CONFIGDIR"/unpack "$ROOT" "$BOOT_ARCHIVE"
 
-    fish "$ROOT"/"$BOOT_FILES"/basis.cm
+    fish "$ROOT"/"$BOOT_FILES"/smlnj/basis
 
     cd "$ROOT"
 
